======
petrus
======

Overview
--------

Create/autocomplete/format a python project and upload it to PyPI.

Installation
------------

To install petrus, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install petrus

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/petrus/#files>`_
* `Source <https://github.com/johannes-programming/petrus>`_

Credits
-------

- Author: Johannes
- Email: johannes-programming@mailfence.com

Thank you for using petrus!